<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 */


if ( ! function_exists( 'blogable_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Blogable 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blogable_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'blogable_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Blogable 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blogable_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'blogable_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blogable_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Blogable 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blogable_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'blogable_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if slider section is enabled.
 *
 * @since  Blogable 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blogable_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blogable_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if blog section is enabled.
 *
 * @since  Blogable 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blogable_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blogable_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if Promotion section is enabled.
 *
 * @since  Blogable 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blogable_is_promotion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blogable_theme_options[promotion_section_enable]' )->value() );
}

/**
 * Check if popular_post section is enabled.
 *
 * @since  Blogable 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blogable_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blogable_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section is enabled.
 *
 * @since  Blogable 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blogable_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blogable_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if stories section is enabled.
 *
 * @since  Blogable 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blogable_is_stories_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blogable_theme_options[stories_section_enable]' )->value() );
}
