<?php
/**
 * Features section
 *
 * This is the template for the content of featured_post section
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 */
if ( ! function_exists( 'blogable_add_featured_post_section' ) ) :
    /**
    * Add featured_post section
    *
    *@since  Blogable 1.0.0
    */
    function blogable_add_featured_post_section() {
    	$options = blogable_get_theme_options();
        // Check if featured_post is enabled on frontpage
        $featured_post_enable = apply_filters( 'blogable_section_status', true, 'featured_post_section_enable' );

        if ( true !== $featured_post_enable ) {
            return false;
        }
        // Get featured_post section details
        $section_details = array();
        $section_details = apply_filters( 'blogable_filter_featured_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_post section now.
        blogable_render_featured_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogable_get_featured_post_section_details' ) ) :
    /**
    * featured_post section details.
    *
    * @since  Blogable 1.0.0
    * @param array $input featured_post section details.
    */
    function blogable_get_featured_post_section_details( $input ) {
        $options = blogable_get_theme_options();

        // Content type.
        $featured_post_count = ! empty( $options['featured_post_count'] ) ? $options['featured_post_count'] : 3;
        
        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= $featured_post_count; $i++ ) {
            if ( ! empty( $options['featured_post_content_page_' . $i] ) ) :
                $page_ids[] = $options['featured_post_content_page_' . $i];
            endif;
        }
        
        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $featured_post_count ),
            'orderby'           => 'post__in',
        );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 0;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blogable_trim_content( 20);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_post section content details.
add_filter( 'blogable_filter_featured_post_section_details', 'blogable_get_featured_post_section_details' );


if ( ! function_exists( 'blogable_render_featured_post_section' ) ) :
  /**
   * Start featured_post section
   *
   * @return string featured_post content
   * @since  Blogable 1.0.0
   *
   */
   function blogable_render_featured_post_section( $content_details = array() ) {
        $options = blogable_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
       <div id="blogable_featured_post_section" class="relative page-section same-background">
            <div id="featured-posts-section">
                <div class="wrapper">
                    <div class="section-contnet col-3 clear">
                        <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="featured-post-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] )?>');">
                                    <a href="<?php echo esc_url( $content['url'] )?>" class="post-thumbnail-link" title="<?php echo esc_url( $content['title'] )?>"></a>
                                </div><!-- .featured-image -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .featured-post-item -->
                        </article>

                        <?php endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- .featured-posts-section -->
       </div>
    <?php 
    }
endif;