<?php
/**
 * Promotion section
 *
 * This is the template for the content of Promotion section
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 */
if ( ! function_exists( 'blogable_add_promotion_section' ) ) :
    /**
    * Add Promotion section
    *
    *@since  Blogable 1.0.0
    */
    function blogable_add_promotion_section() {
        $options = blogable_get_theme_options();
        
        // Check if Promotion is enabled on frontpage
        $promotion_enable = apply_filters( 'blogable_section_status', true, 'promotion_section_enable' );

        if ( true !== $promotion_enable ) {
            return false;
        }

        // Get Promotion section details
        $section_details = array();
        $section_details = apply_filters( 'blogable_filter_promotion_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Promotion section now.
        blogable_render_promotion_section( $section_details[0] );
    }
endif;

if ( ! function_exists( 'blogable_get_promotion_section_details' ) ) :
    /**
    * Promotion section details.
    *
    * @since  Blogable 1.0.0
    * @param array $input Promotion section details.
    */
    function blogable_get_promotion_section_details( $input ) {
        $options = blogable_get_theme_options();

        
        $content = array();
        $page_id = ! empty( $options['promotion_content_page'] ) ? $options['promotion_content_page'] : '';
        $args = array(
            'post_type'             => 'page',
            'posts_per_page'        => 1,
            'p'                     => $page_id,
            'ignore_sticky_posts'   => true,
        );                    

    
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blogable_trim_content( 30 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Promotion section content details.
add_filter( 'blogable_filter_promotion_section_details', 'blogable_get_promotion_section_details' );


if ( ! function_exists( 'blogable_render_promotion_section' ) ) :
  /**
   * Start Promotion section
   *
   * @return string Promotion content
   * @since  Blogable 1.0.0
   *
   */
   function blogable_render_promotion_section( $content_details = array() ) {
        $options    = blogable_get_theme_options();
        $btn_label  = $options['promotion_read_more'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="blogable_promotion_section" class="relative page-section" style="background-image: url('<?php echo esc_url($content_details['image']); ?>');">
            <div id="promotion-section">
                <div class="overlay"></div>

                <div class="wrapper">
                    <header class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html($content_details['title']); ?></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo wp_kses_post($content_details['excerpt']); ?></p>
                    </div><!-- .entry-content -->
                    <?php if ( !empty( $btn_label ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url($content_details['url']); ?>" class="btn"><?php echo esc_html($btn_label); ?></a>
                        </div>
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #promotion-section -->
        </div>
     
       
    <?php }
endif;